<?php
/**
 * Orders grid container block
 *
 * @category   Turnkeye
 * @package    Turnkeye_Xcartorders
 * @author     Viacheslav Fedorenko <v.fedorenko@turnkeye.com>
 */

class Turnkeye_Xcartorders_Block_Adminhtml_Xcartorder_Grid extends Mage_Adminhtml_Block_Widget_Grid
{
    public function __construct()
    {
        parent::__construct();
        $this->setId('turnkeye_xcartordersGrid');
        $this->setDefaultSort('date');
        $this->setDefaultDir('DESC');
        $this->setSaveParametersInSession(true);
    }

    protected function _prepareCollection()
    {
        $collection = Mage::getModel('turnkeye_xcartorders/order')->getCollection();
        $collection->addExpressionFieldToSelect('billing_name', 'CONCAT({{firstname}}, " ", {{lastname}})', array('firstname' => 'firstname', 'lastname' => 'lastname'));
        $collection->addExpressionFieldToSelect('shipping_name', 'CONCAT({{firstname}}, " ", {{lastname}})', array('firstname' => 's_firstname', 'lastname' => 's_lastname'));
        $this->setCollection($collection);
        return parent::_prepareCollection();
    }

    protected function _prepareColumns()
    {
        $this->addColumn('orderid', array(
            'header'=> Mage::helper('sales')->__('Xcart Order #'),
            'width' => '80px',
            'type'  => 'text',
            'index' => 'orderid',
        ));

        $this->addColumn('date', array(
            'header' => Mage::helper('sales')->__('Purchased On'),
            'index' => 'date',
            'type' => 'datetime',
            'width' => '100px',
            'renderer' => 'turnkeye_xcartorders/adminhtml_xcartorder_grid_renderer_date'
        ));

        $this->addColumn('billing_name', array(
            'header' => Mage::helper('sales')->__('Bill to Name'),
            'index' => array('firstname', 'lastname'),
            'type'  => 'concat',
            'separator' => ' ',
            'filter_index' => 'billing_name'
        ));

        $this->addColumn('shipping_name', array(
            'header' => Mage::helper('sales')->__('Ship to Name'),
            'index' => array('s_firstname', 's_lastname'),
            'type'  => 'concat',
            'separator' => ' ',
            'filter_index' => 'shipping_name'
        ));

        $this->addColumn('total', array(
            'header' => Mage::helper('sales')->__('G.T. (Base)'),
            'index' => 'total',
            'type'  => 'currency',
            'currency' => 'base_currency_code',
        ));

        $this->addColumn('status', array(
            'header' => Mage::helper('sales')->__('Status'),
            'index' => 'status',
            'type'  => 'options',
            'width' => '70px',
            'options' => Mage::getSingleton('turnkeye_xcartorders/order_config')->getStatuses(),
        ));

        if (Mage::getSingleton('admin/session')->isAllowed('sales/order/actions/view')) {
            $this->addColumn('action',
                array(
                    'header'    => Mage::helper('sales')->__('Action'),
                    'width'     => '50px',
                    'type'      => 'action',
                    'getter'     => 'getId',
                    'actions'   => array(
                        array(
                            'caption' => Mage::helper('sales')->__('View'),
                            'url'     => array('base'=>'*/*/view'),
                            'field'   => 'id'
                        )
                    ),
                    'filter'    => false,
                    'sortable'  => false,
                    'index'     => 'stores',
                    'is_system' => true,
                ));
        }

        return parent::_prepareColumns();
    }

    public function getRowUrl($row)
    {
        return $this->getUrl('*/*/view', array('id' => $row->getId()));
    }

    protected function _prepareMassaction_bak()
    {
        $this->setMassactionIdField('id');
        $this->getMassactionBlock()->setFormFieldName('brand_ids');

        $this->getMassactionBlock()->addItem('delete', array(
             'label'    => Mage::helper('turnkeye_brand')->__('Delete'),
             'url'      => $this->getUrl('*/*/massDelete'),
             'confirm'  => Mage::helper('turnkeye_brand')->__('Are you sure?')
        ));

        return $this;
    }

    protected function _addColumnFilterToCollection($column)
    {
        if ($this->getCollection() && in_array($column->getFilterIndex(), array('billing_name', 'shipping_name'))) {
            $value = $column->getFilter()->getValue();
            $prefix = '';
            if ($column->getFilterIndex() == 'billing_name') {
                $prefix = '';
            } else if ($column->getFilterIndex() == 'shipping_name') {
                $prefix = 's_';
            }

            if ($value) {
                $this->getCollection()->addFieldToFilter(array($prefix . 'firstname' => $prefix . 'firstname', $prefix . 'lastname' => $prefix . 'lastname'), array($prefix . 'firstname' => array('like' => '%' . $value . '%'), $prefix . 'lastname' => array('like' => '%' . $value . '%')));
            }
        } else if ($column->getIndex() == 'date') {
            $val = $column->getFilter()->getCondition();
            if ($val && isset($val['to'])) {
                $this->getCollection()->addFieldToFilter('date', array('to' => $val['to']->getTimestamp()));
            }
            if ($val && isset($val['from'])) {
                $this->getCollection()->addFieldToFilter('date', array('from' => $val['from']->getTimestamp()));
            }
        } else {
            return parent::_addColumnFilterToCollection($column);
        }

        return $this;
    }
}
